Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/circuitpython_schedule_simpletest.py
    :caption: examples/circuitpython_schedule_simpletest.py
    :linenos:


Additional utilities
---------------------

Additional utilities that are available

.. literalinclude:: ../examples/circuitpython_schedule_util.py
    :caption: examples/circuitpython_schedule_util.py
    :linenos:


Real Time Clock
----------------

This module works great in combination with a Real Time Clock (RTC), if one is
available on your device.  For example:

.. literalinclude:: ../examples/circuitpython_schedule_rtc.py
    :caption: examples/circuitpython_schedule_rtc.py
    :linenos:
